@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from django.core.handlers.wsgi import WSGIRequest
+from django.core.signals import got_request_exception
 from django.db import models
 from django.test.client import Client
 from django.test import TestCase
@@ -158,7 +159,7 @@ class DBLogTestCase(TestCase):
         try:
             Error.objects.get(id=999999999)
         except Error.DoesNotExist, exc:
-            DBLogMiddleware().process_exception(request, exc)
+            ErrorBatch.handle_exception(request=request, sender=self)
         else:
             self.fail('Unable to create `Error` entry.')
         
@@ -297,9 +298,9 @@ class DBLogTestCase(TestCase):
         try:
             Error.objects.get(id=999999999)
         except Error.DoesNotExist, exc:
-            DBLogMiddleware().process_exception(request, exc)
+            ErrorBatch.handle_exception(request=request, sender=self)
         else:
-            self.fail('Unable to create `Error` entry.')
+            self.fail('Expected an exception.')
         
         cur = (Error.objects.count(), ErrorBatch.objects.count())
         self.assertEquals(cur, (1, 1), 'Assumed logs failed to save. %s' % (cur,))
@@ -318,9 +319,9 @@ class DBLogTestCase(TestCase):
         try:
             Error.objects.get(id=999999999)
         except Error.DoesNotExist, exc:
-            DBLogMiddleware().process_exception(request, exc)
+            ErrorBatch.handle_exception(request=request, sender=self)
         else:
-            self.fail('Unable to create `Error` entry.')
+            self.fail('Expected an exception.')
         
         cur = (Error.objects.count(), ErrorBatch.objects.count())
         self.assertEquals(cur, (1, 1), 'Assumed logs failed to save. %s' % (cur,))
@@ -334,4 +335,25 @@ class DBLogTestCase(TestCase):
         for i in range(0, 50):
             Error.objects.create_from_text('hi')
         
-        self.assertEquals(Error.objects.count(), settings.THRASHING_LIMIT)
\ No newline at end of file
+        self.assertEquals(Error.objects.count(), settings.THRASHING_LIMIT)
+    
+    def testSignals(self):
+        Error.objects.all().delete()
+        ErrorBatch.objects.all().delete()
+
+        request = RF.get("/", REMOTE_ADDR="127.0.0.1:8000")
+
+        try:
+            Error.objects.get(id=999999999)
+        except Error.DoesNotExist, exc:
+            got_request_exception.send(sender=self.__class__, request=request)
+        else:
+            self.fail('Expected an exception.')
+            
+        cur = (Error.objects.count(), ErrorBatch.objects.count())
+        self.assertEquals(cur, (1, 1), 'Assumed logs failed to save. %s' % (cur,))
+        last = Error.objects.all().order_by('-id')[0:1].get()
+        self.assertEquals(last.logger, 'root')
+        self.assertEquals(last.class_name, 'DoesNotExist')
+        self.assertEquals(last.level, logging.ERROR)
+        self.assertEquals(last.message, smart_unicode(exc))        
